@@ -16,9 +16,9 @@ class Prawn::SVG::Elements::Polygon < Prawn::SVG::Elements::Base
   def commands
     @commands ||= [
       Prawn::SVG::Pathable::Move.new(@points[0])
-    ] + @points[1..].map { |point|
+    ] + @points[1..].map do |point|
       Prawn::SVG::Pathable::Line.new(point)
-    } + [
+    end + [
       Prawn::SVG::Pathable::Close.new(@points[0])
     ]
   end
